@@ -2,7 +2,7 @@ package Dezi;
 use warnings;
 use strict;
 
-our $VERSION = '0.001002';
+our $VERSION = '0.001003';
 
 1;
 
@@ -58,6 +58,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<https://groups.google.com/forum/#!forum/dezi-search>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dezi>
